#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
#include <assert.h>


#ifdef DEBUG
#define DBG(x) x
#else
#define DBG(x)
#endif

#define TYPEVAL 1
#define TYPESUB 2

typedef struct One {
	int type;
	int val;
	struct One * next;
	struct One * sub;
} One;

One * new () {
	One * t;
	t = malloc (sizeof (One));
	t->next = t->sub = NULL;
	t->type = t->val = -1;
	return t;
}

One * parse (char * line, int pos, int end);

One * parseOne (char * line, int * pos) {
	int vlen,  val, depth, npos;
	One * ret;
	if (sscanf (&line[*pos], "%d%n", &val, &vlen) > 0) {
		ret = new ();
		ret->type = TYPEVAL;
		ret->val = val;
		ret->sub = NULL;
		ret->next = NULL;
		(*pos) += vlen;
		return ret;
	}
	while (line[*pos] && (line[*pos] != '(')) {
		(*pos)++;
	}
	if (!line[*pos]) return NULL;
	depth = 1;
	npos = (*pos) + 1;
	while (depth) {
		if (line[npos] == '(') depth++;
		if (line[npos] == ')') depth--;
		npos++;
	}
	return parse (line, (*pos)+1, npos-1);
}


One * parse (char * line, int pos, int end) {
	One * ret = NULL, *tmp, **last;
	ret = NULL;
	last = &ret;
	while (1) {
		while (isspace (line[pos])) pos++;
		if (pos > end) return ret;
		tmp = parseOne (line, &pos);
		(*last) = tmp;
		if (tmp == NULL)
			return ret;
		(*last) = (*last)->next;
	}
}


int do_op (int val1, int op, int val2) {
	switch (op) {
	case 0:	return val1 + val2;
	case 1: return val1 - val2;
	case 2: return val1 * val2;
	}
	return -1;
}

int start (char * p) {
	int i = 0;
	while (p[i]) if (p[i++] == '=') return i;
	return 0;
}

int eval (One * exp, int * ops, int * opos) {
	One * p; int ret = 0, op;

	p = exp;
	while (p) {
		op = ops[*opos];
		(*opos)++;
		if (p->sub) {
			ret = do_op (ret, op, eval (p->sub, ops, opos));
		} else {
			ret = do_op (ret, op, p->val);
		}
	
	}
	return ret;
}

void PrintExp (One * exp, int * ops, int * opos) {
	One * p; int op;
	char sops[10] = "+-*";

	p = exp;
	while (p) {
		op = ops[*opos];
		if ((*opos) != 0) printf ("%c", sops[op]);
		(*opos)++;
		if (p->sub) {
			PrintExp (p->sub, ops, opos);
		} else {
			printf ("%d", p->val);
		}
	
	}
}


int gops[20];

int next (int len) {
	int i = 0,j;
	while (gops[len - i] == 2) i++;
	gops[len-i]++;
	for (j = len -i+1; j<len; ++j) gops[j] = 0;
	if (gops[0] > 0) return 0;
	return 1;
}

FILE * in;

int main () {
	char line[100]; int pos, opos, olen;
	One * exp;
	int kase = 0, lhs, ret, i, j;
	
	in = fopen ("dreisam.in", "r");
	while (1) {
		fgets (line,100, in);
		pos = start (line);
		if (pos == 0) break;
		pos++;
		sscanf (line, "%d", &lhs);
		exp = parse (line, pos, strlen (line));
		for (i=0; i<20; ++i) gops[i] = 0; olen = 0;
		eval (exp, gops, &olen);
		do {
			opos = 0;
			ret = eval (exp, gops, &opos);
			if (ret == lhs) break;
		} while (next (olen));
		printf ("Equation #%d:\n", ++kase);
		if (ret == lhs) {
			opos = 0;
			PrintExp (exp, gops, &opos);
			printf ("\n\n");
		} else {
			printf ("Impossible\n\n");
		}
	}
	return 0;
}


